@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2003-2017 Anope Team
+ * (C) 2003-2019 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -952,7 +952,7 @@ class MyManager : public Manager, public Timer
 
 			packet->questions.push_back(Question(zone, QUERY_SOA));
 
-			new NotifySocket(ip.find(':') != Anope::string::npos ? AF_INET6 : AF_INET, packet);
+			new NotifySocket(ip.find(':') != Anope::string::npos, packet);
 		}
 	}
 
